==> u61-0.1.1.tar.gz: u61-0.1.1/src/aboutmenu.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   aboutmenu.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: the about menu tells the end-user what U61 is
 *              and explains its free software status
 */

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "aboutmenu.h"
#include "text.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/* 
 * creation of the empty menu
 */ 
U61_AboutMenu::U61_AboutMenu(U61_Menu *parent) 
    : U61_Menu(parent,"U61 by U-Foot")
{
    add_item(new U61_Text("U61 is another block-based game"));
    add_item(new U61_Text(" "));
    add_item(new U61_Text("Copyright (C) 2000 Christian Mauduit"));
    add_item(new U61_Text(" "));
    add_item(new U61_Text("U61 is a free software, protected by the GPL"));
    add_item(new U61_Text
       ("You can use it, copy it, modify it and redistribute it"));
    add_item(new U61_Text("as long as it always stays free software"));
    add_item(new U61_Text
       ("The source code is available on http://sourceforge.net"));
    add_item(new U61_Text("See copying.txt or COPYING for more information"));
    add_item(new U61_Text(" "));
    add_item(new U61_Text("Web site : http://www.ufoot.org/u61"));
    add_item(new U61_Text("Contact author : ufoot@ufoot.org"));
    select(0);
}

/*--------------------------------------------------------------------------*/
/*
 * this function does nothing, this way the player sees plain text
 */
void U61_AboutMenu::select_up()
{
    
}

/*--------------------------------------------------------------------------*/
/*
 * this function does nothing, this way the player sees plain text
 */
void U61_AboutMenu::select_down()
{
    
}

==> u61-0.1.3.tar.gz: u61-0.1.3/src/aboutmenu.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   aboutmenu.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: the about menu tells the end-user what U61 is
 *              and explains its free software status
 */

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "aboutmenu.h"
#include "text.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/* 
 * creation of the empty menu
 */ 
U61_AboutMenu::U61_AboutMenu(U61_Menu *parent) 
    : U61_Menu(parent,"U61 by U-Foot")
{
    add_item(new U61_Text("U61, another block-based game"));
    add_item(new U61_Text(" "));
    add_item(new U61_Text("Copyright (C) 2000"));
    add_item(new U61_Text(" "));
    add_item(new U61_Text("Author: Christian Mauduit"));
    add_item(new U61_Text("License: free software (GPL)"));
    add_item(new U61_Text("Home: www.ufoot.org/u61"));
    add_item(new U61_Text("Contact: ufoot@ufoot.org"));
    select(0);
}

/*--------------------------------------------------------------------------*/
/*
 * this function does nothing, this way the player sees plain text
 */
void U61_AboutMenu::select_up()
{
    
}

/*--------------------------------------------------------------------------*/
/*
 * this function does nothing, this way the player sees plain text
 */
void U61_AboutMenu::select_down()
{
    
}
